@@ -21,14 +21,14 @@ function generate_testr_results {
         sudo /usr/os-testr-env/bin/subunit2html $BASE/logs/testrepository.subunit $BASE/logs/testr_results.html
         sudo gzip -9 $BASE/logs/testrepository.subunit
         sudo gzip -9 $BASE/logs/testr_results.html
-        sudo chown jenkins:jenkins $BASE/logs/testrepository.subunit.gz $BASE/logs/testr_results.html.gz
+        sudo chown $USER:$USER $BASE/logs/testrepository.subunit.gz $BASE/logs/testr_results.html.gz
         sudo chmod a+r $BASE/logs/testrepository.subunit.gz $BASE/logs/testr_results.html.gz
     fi
 }
 
 export MURANOCLIENT_DIR="$BASE/new/python-muranoclient"
 
-sudo chown -R jenkins:stack $MURANOCLIENT_DIR
+sudo chown -R $USER:stack $MURANOCLIENT_DIR
 
 # Get admin credentials
 cd $BASE/new/devstack
@@ -51,13 +51,13 @@ EOF
 # Go to the muranoclient dir
 cd $MURANOCLIENT_DIR
 
-sudo chown -R jenkins:stack $MURANOCLIENT_DIR
+sudo chown -R $USER:stack $MURANOCLIENT_DIR
 
 # Run tests
 echo "Running muranoclient functional test suite"
 set +e
 # Preserve env for OS_ credentials
-sudo -E -H -u jenkins tox -efunctional
+sudo -E -H -u $USER tox -efunctional
 EXIT_CODE=$?
 set -e
 
